Index: to-akpm/drivers/acpi/ec.c
===================================================================
--- to-akpm.orig/drivers/acpi/ec.c
+++ to-akpm/drivers/acpi/ec.c
@@ -38,130 +38,112 @@
 #include <acpi/actypes.h>
 
 #define _COMPONENT		ACPI_EC_COMPONENT
-ACPI_MODULE_NAME		("acpi_ec")
-
+ACPI_MODULE_NAME("acpi_ec")
 #define ACPI_EC_COMPONENT		0x00100000
 #define ACPI_EC_CLASS			"embedded_controller"
 #define ACPI_EC_HID			"PNP0C09"
 #define ACPI_EC_DRIVER_NAME		"ACPI Embedded Controller Driver"
 #define ACPI_EC_DEVICE_NAME		"Embedded Controller"
 #define ACPI_EC_FILE_INFO		"info"
-
-
 #define ACPI_EC_FLAG_OBF	0x01	/* Output buffer full */
 #define ACPI_EC_FLAG_IBF	0x02	/* Input buffer full */
 #define ACPI_EC_FLAG_BURST	0x10	/* burst mode */
 #define ACPI_EC_FLAG_SCI	0x20	/* EC-SCI occurred */
-
 #define ACPI_EC_EVENT_OBF	0x01	/* Output buffer full */
 #define ACPI_EC_EVENT_IBE	0x02	/* Input buffer empty */
-
 #define ACPI_EC_DELAY		50	/* Wait 50ms max. during EC ops */
 #define ACPI_EC_UDELAY_GLK	1000	/* Wait 1ms max. to get global lock */
-
-#define ACPI_EC_UDELAY         100     /* Poll @ 100us increments */
-#define ACPI_EC_UDELAY_COUNT   1000    /* Wait 10ms max. during EC ops */
-
+#define ACPI_EC_UDELAY         100	/* Poll @ 100us increments */
+#define ACPI_EC_UDELAY_COUNT   1000	/* Wait 10ms max. during EC ops */
 #define ACPI_EC_COMMAND_READ	0x80
 #define ACPI_EC_COMMAND_WRITE	0x81
 #define ACPI_EC_BURST_ENABLE	0x82
 #define ACPI_EC_BURST_DISABLE	0x83
 #define ACPI_EC_COMMAND_QUERY	0x84
-
 #define EC_POLLING		0xFF
 #define EC_BURST		0x00
-
-
-static int acpi_ec_remove (struct acpi_device *device, int type);
-static int acpi_ec_start (struct acpi_device *device);
-static int acpi_ec_stop (struct acpi_device *device, int type);
-static int acpi_ec_burst_add ( struct acpi_device *device);
-static int acpi_ec_polling_add ( struct acpi_device	*device);
+static int acpi_ec_remove(struct acpi_device *device, int type);
+static int acpi_ec_start(struct acpi_device *device);
+static int acpi_ec_stop(struct acpi_device *device, int type);
+static int acpi_ec_burst_add(struct acpi_device *device);
+static int acpi_ec_polling_add(struct acpi_device *device);
 
 static struct acpi_driver acpi_ec_driver = {
-	.name =		ACPI_EC_DRIVER_NAME,
-	.class =	ACPI_EC_CLASS,
-	.ids =		ACPI_EC_HID,
-	.ops =		{
-				.add =		acpi_ec_polling_add,
-				.remove =	acpi_ec_remove,
-				.start =	acpi_ec_start,
-				.stop =		acpi_ec_stop,
-			},
+	.name = ACPI_EC_DRIVER_NAME,
+	.class = ACPI_EC_CLASS,
+	.ids = ACPI_EC_HID,
+	.ops = {
+		.add = acpi_ec_polling_add,
+		.remove = acpi_ec_remove,
+		.start = acpi_ec_start,
+		.stop = acpi_ec_stop,
+		},
 };
 union acpi_ec {
 	struct {
-		u32				mode;
-		acpi_handle			handle;
-		unsigned long			uid;
-		unsigned long			gpe_bit;
-		struct acpi_generic_address	status_addr;
-		struct acpi_generic_address	command_addr;
-		struct acpi_generic_address	data_addr;
-		unsigned long			global_lock;
+		u32 mode;
+		acpi_handle handle;
+		unsigned long uid;
+		unsigned long gpe_bit;
+		struct acpi_generic_address status_addr;
+		struct acpi_generic_address command_addr;
+		struct acpi_generic_address data_addr;
+		unsigned long global_lock;
 	} common;
 
 	struct {
-		u32				mode;
-		acpi_handle			handle;
-		unsigned long			uid;
-		unsigned long			gpe_bit;
-		struct acpi_generic_address	status_addr;
-		struct acpi_generic_address	command_addr;
-		struct acpi_generic_address	data_addr;
-		unsigned long			global_lock;
-		unsigned int			expect_event;
-		atomic_t			leaving_burst; /* 0 : No, 1 : Yes, 2: abort*/
-		atomic_t			pending_gpe;
-		struct semaphore		sem;
-		wait_queue_head_t		wait;
-	}burst;
+		u32 mode;
+		acpi_handle handle;
+		unsigned long uid;
+		unsigned long gpe_bit;
+		struct acpi_generic_address status_addr;
+		struct acpi_generic_address command_addr;
+		struct acpi_generic_address data_addr;
+		unsigned long global_lock;
+		unsigned int expect_event;
+		atomic_t leaving_burst;	/* 0 : No, 1 : Yes, 2: abort */
+		atomic_t pending_gpe;
+		struct semaphore sem;
+		wait_queue_head_t wait;
+	} burst;
 
 	struct {
-		u32				mode;
-		acpi_handle			handle;
-		unsigned long			uid;
-		unsigned long			gpe_bit;
-		struct acpi_generic_address	status_addr;
-		struct acpi_generic_address	command_addr;
-		struct acpi_generic_address	data_addr;
-		unsigned long			global_lock;
-       		spinlock_t                      lock;
-	}polling;
+		u32 mode;
+		acpi_handle handle;
+		unsigned long uid;
+		unsigned long gpe_bit;
+		struct acpi_generic_address status_addr;
+		struct acpi_generic_address command_addr;
+		struct acpi_generic_address data_addr;
+		unsigned long global_lock;
+		spinlock_t lock;
+	} polling;
 };
 
-static int acpi_ec_polling_wait ( union acpi_ec *ec, u8 event); 
+static int acpi_ec_polling_wait(union acpi_ec *ec, u8 event);
 static int acpi_ec_burst_wait(union acpi_ec *ec, unsigned int event);
-static int acpi_ec_polling_read ( union acpi_ec *ec, u8 address, u32 *data);
-static int acpi_ec_burst_read( union acpi_ec *ec, u8 address, u32 *data);
-static int acpi_ec_polling_write ( union acpi_ec *ec, u8 address, u8 data);
-static int acpi_ec_burst_write ( union acpi_ec *ec, u8 address, u8 data);
-static int acpi_ec_polling_query ( union acpi_ec *ec, u32 *data);
-static int acpi_ec_burst_query ( union acpi_ec *ec, u32 *data);
-static void acpi_ec_gpe_polling_query ( void *ec_cxt);
-static void acpi_ec_gpe_burst_query ( void *ec_cxt);
-static u32 acpi_ec_gpe_polling_handler ( void *data);
-static u32 acpi_ec_gpe_burst_handler ( void *data);
+static int acpi_ec_polling_read(union acpi_ec *ec, u8 address, u32 * data);
+static int acpi_ec_burst_read(union acpi_ec *ec, u8 address, u32 * data);
+static int acpi_ec_polling_write(union acpi_ec *ec, u8 address, u8 data);
+static int acpi_ec_burst_write(union acpi_ec *ec, u8 address, u8 data);
+static int acpi_ec_polling_query(union acpi_ec *ec, u32 * data);
+static int acpi_ec_burst_query(union acpi_ec *ec, u32 * data);
+static void acpi_ec_gpe_polling_query(void *ec_cxt);
+static void acpi_ec_gpe_burst_query(void *ec_cxt);
+static u32 acpi_ec_gpe_polling_handler(void *data);
+static u32 acpi_ec_gpe_burst_handler(void *data);
 static acpi_status __init
-acpi_fake_ecdt_polling_callback (
-	acpi_handle	handle,
-	u32		Level,
-	void		*context,
-	void		**retval);
+acpi_fake_ecdt_polling_callback(acpi_handle handle,
+				u32 Level, void *context, void **retval);
 
 static acpi_status __init
-acpi_fake_ecdt_burst_callback (
-	acpi_handle	handle,
-	u32		Level,
-	void		*context,
-	void		**retval);
-
-static int __init
-acpi_ec_polling_get_real_ecdt(void);
-static int __init
-acpi_ec_burst_get_real_ecdt(void);
+acpi_fake_ecdt_burst_callback(acpi_handle handle,
+			      u32 Level, void *context, void **retval);
+
+static int __init acpi_ec_polling_get_real_ecdt(void);
+static int __init acpi_ec_burst_get_real_ecdt(void);
 /* If we find an EC via the ECDT, we need to keep a ptr to its context */
-static union acpi_ec	*ec_ecdt;
+static union acpi_ec *ec_ecdt;
 
 /* External interfaces use first EC only, so remember */
 static struct acpi_device *first_ec;
@@ -173,30 +155,24 @@ static int acpi_ec_polling_mode = EC_POL
 
 static inline u32 acpi_ec_read_status(union acpi_ec *ec)
 {
-	u32	status = 0;
+	u32 status = 0;
 
 	acpi_hw_low_level_read(8, &status, &ec->common.status_addr);
 	return status;
 }
 
-static int
-acpi_ec_wait (
-	union acpi_ec		*ec,
-	u8			event)
+static int acpi_ec_wait(union acpi_ec *ec, u8 event)
 {
-	if (acpi_ec_polling_mode) 
-		return acpi_ec_polling_wait (ec, event);
+	if (acpi_ec_polling_mode)
+		return acpi_ec_polling_wait(ec, event);
 	else
-		return acpi_ec_burst_wait (ec, event);
+		return acpi_ec_burst_wait(ec, event);
 }
 
-static int
-acpi_ec_polling_wait (
-	union acpi_ec		*ec,
-	u8			event)
+static int acpi_ec_polling_wait(union acpi_ec *ec, u8 event)
 {
-	u32			acpi_ec_status = 0;
-	u32			i = ACPI_EC_UDELAY_COUNT;
+	u32 acpi_ec_status = 0;
+	u32 i = ACPI_EC_UDELAY_COUNT;
 
 	if (!ec)
 		return -EINVAL;
@@ -205,19 +181,21 @@ acpi_ec_polling_wait (
 	switch (event) {
 	case ACPI_EC_EVENT_OBF:
 		do {
-			acpi_hw_low_level_read(8, &acpi_ec_status, &ec->common.status_addr);
+			acpi_hw_low_level_read(8, &acpi_ec_status,
+					       &ec->common.status_addr);
 			if (acpi_ec_status & ACPI_EC_FLAG_OBF)
 				return 0;
 			udelay(ACPI_EC_UDELAY);
-		} while (--i>0);
+		} while (--i > 0);
 		break;
 	case ACPI_EC_EVENT_IBE:
 		do {
-			acpi_hw_low_level_read(8, &acpi_ec_status, &ec->common.status_addr);
+			acpi_hw_low_level_read(8, &acpi_ec_status,
+					       &ec->common.status_addr);
 			if (!(acpi_ec_status & ACPI_EC_FLAG_IBF))
 				return 0;
 			udelay(ACPI_EC_UDELAY);
-		} while (--i>0);
+		} while (--i > 0);
 		break;
 	default:
 		return -EINVAL;
@@ -227,7 +205,7 @@ acpi_ec_polling_wait (
 }
 static int acpi_ec_burst_wait(union acpi_ec *ec, unsigned int event)
 {
-	int	result = 0;
+	int result = 0;
 
 	ACPI_FUNCTION_TRACE("acpi_ec_wait");
 
@@ -251,9 +229,9 @@ static int acpi_ec_burst_wait(union acpi
 	}
 
 	result = wait_event_timeout(ec->burst.wait,
-					!ec->burst.expect_event,
-					msecs_to_jiffies(ACPI_EC_DELAY));
-	
+				    !ec->burst.expect_event,
+				    msecs_to_jiffies(ACPI_EC_DELAY));
+
 	ec->burst.expect_event = 0;
 	smp_mb();
 
@@ -277,43 +255,37 @@ static int acpi_ec_burst_wait(union acpi
 	return_VALUE(-ETIME);
 }
 
-
-
-static int
-acpi_ec_enter_burst_mode (
-	union acpi_ec		*ec)
+static int acpi_ec_enter_burst_mode(union acpi_ec *ec)
 {
-	u32			tmp = 0;
-	int			status = 0;
+	u32 tmp = 0;
+	int status = 0;
 
 	ACPI_FUNCTION_TRACE("acpi_ec_enter_burst_mode");
 
 	status = acpi_ec_read_status(ec);
-	if (status != -EINVAL &&
-		!(status & ACPI_EC_FLAG_BURST)){
+	if (status != -EINVAL && !(status & ACPI_EC_FLAG_BURST)) {
 		status = acpi_ec_wait(ec, ACPI_EC_EVENT_IBE);
-		if(status)
+		if (status)
 			goto end;
-		acpi_hw_low_level_write(8, ACPI_EC_BURST_ENABLE, &ec->common.command_addr);
+		acpi_hw_low_level_write(8, ACPI_EC_BURST_ENABLE,
+					&ec->common.command_addr);
 		status = acpi_ec_wait(ec, ACPI_EC_EVENT_OBF);
 		if (status)
 			return_VALUE(-EINVAL);
 		acpi_hw_low_level_read(8, &tmp, &ec->common.data_addr);
-		if(tmp != 0x90 ) {/* Burst ACK byte*/
+		if (tmp != 0x90) {	/* Burst ACK byte */
 			return_VALUE(-EINVAL);
 		}
 	}
 
-	atomic_set(&ec->burst.leaving_burst , 0);
+	atomic_set(&ec->burst.leaving_burst, 0);
 	return_VALUE(0);
-end:
+      end:
 	printk("Error in acpi_ec_wait\n");
 	return_VALUE(-1);
 }
 
-static int
-acpi_ec_leave_burst_mode (
-	union acpi_ec		*ec)
+static int acpi_ec_leave_burst_mode(union acpi_ec *ec)
 {
 
 	ACPI_FUNCTION_TRACE("acpi_ec_leave_burst_mode");
@@ -322,38 +294,26 @@ acpi_ec_leave_burst_mode (
 	return_VALUE(0);
 }
 
-static int
-acpi_ec_read (
-	union acpi_ec		*ec,
-	u8			address,
-	u32			*data)
+static int acpi_ec_read(union acpi_ec *ec, u8 address, u32 * data)
 {
-	if (acpi_ec_polling_mode) 
+	if (acpi_ec_polling_mode)
 		return acpi_ec_polling_read(ec, address, data);
 	else
 		return acpi_ec_burst_read(ec, address, data);
 }
-static int
-acpi_ec_write (
-	union acpi_ec		*ec,
-	u8			address,
-	u8			data)
+static int acpi_ec_write(union acpi_ec *ec, u8 address, u8 data)
 {
-	if (acpi_ec_polling_mode) 
+	if (acpi_ec_polling_mode)
 		return acpi_ec_polling_write(ec, address, data);
 	else
 		return acpi_ec_burst_write(ec, address, data);
 }
-static int
-acpi_ec_polling_read (
-	union acpi_ec		*ec,
-	u8			address,
-	u32			*data)
-{
-	acpi_status		status = AE_OK;
-	int			result = 0;
-	unsigned long		flags = 0;
-	u32			glk = 0;
+static int acpi_ec_polling_read(union acpi_ec *ec, u8 address, u32 * data)
+{
+	acpi_status status = AE_OK;
+	int result = 0;
+	unsigned long flags = 0;
+	u32 glk = 0;
 
 	ACPI_FUNCTION_TRACE("acpi_ec_read");
 
@@ -370,7 +330,8 @@ acpi_ec_polling_read (
 
 	spin_lock_irqsave(&ec->polling.lock, flags);
 
-	acpi_hw_low_level_write(8, ACPI_EC_COMMAND_READ, &ec->common.command_addr);
+	acpi_hw_low_level_write(8, ACPI_EC_COMMAND_READ,
+				&ec->common.command_addr);
 	result = acpi_ec_wait(ec, ACPI_EC_EVENT_IBE);
 	if (result)
 		goto end;
@@ -383,9 +344,9 @@ acpi_ec_polling_read (
 	acpi_hw_low_level_read(8, data, &ec->common.data_addr);
 
 	ACPI_DEBUG_PRINT((ACPI_DB_INFO, "Read [%02x] from address [%02x]\n",
-		*data, address));
-	
-end:
+			  *data, address));
+
+      end:
 	spin_unlock_irqrestore(&ec->polling.lock, flags);
 
 	if (ec->common.global_lock)
@@ -394,17 +355,12 @@ end:
 	return_VALUE(result);
 }
 
-
-static int
-acpi_ec_polling_write (
-	union acpi_ec		*ec,
-	u8			address,
-	u8			data)
-{
-	int			result = 0;
-	acpi_status		status = AE_OK;
-	unsigned long		flags = 0;
-	u32			glk = 0;
+static int acpi_ec_polling_write(union acpi_ec *ec, u8 address, u8 data)
+{
+	int result = 0;
+	acpi_status status = AE_OK;
+	unsigned long flags = 0;
+	u32 glk = 0;
 
 	ACPI_FUNCTION_TRACE("acpi_ec_write");
 
@@ -419,7 +375,8 @@ acpi_ec_polling_write (
 
 	spin_lock_irqsave(&ec->polling.lock, flags);
 
-	acpi_hw_low_level_write(8, ACPI_EC_COMMAND_WRITE, &ec->common.command_addr);
+	acpi_hw_low_level_write(8, ACPI_EC_COMMAND_WRITE,
+				&ec->common.command_addr);
 	result = acpi_ec_wait(ec, ACPI_EC_EVENT_IBE);
 	if (result)
 		goto end;
@@ -435,9 +392,9 @@ acpi_ec_polling_write (
 		goto end;
 
 	ACPI_DEBUG_PRINT((ACPI_DB_INFO, "Wrote [%02x] to address [%02x]\n",
-		data, address));
+			  data, address));
 
-end:
+      end:
 	spin_unlock_irqrestore(&ec->polling.lock, flags);
 
 	if (ec->common.global_lock)
@@ -446,14 +403,10 @@ end:
 	return_VALUE(result);
 }
 
-static int
-acpi_ec_burst_read (
-	union acpi_ec		*ec,
-	u8			address,
-	u32			*data)
+static int acpi_ec_burst_read(union acpi_ec *ec, u8 address, u32 * data)
 {
-	int			status = 0;
-	u32			glk;
+	int status = 0;
+	u32 glk;
 
 	ACPI_FUNCTION_TRACE("acpi_ec_read");
 
@@ -477,23 +430,24 @@ acpi_ec_burst_read (
 		printk("read EC, IB not empty\n");
 		goto end;
 	}
-	acpi_hw_low_level_write(8, ACPI_EC_COMMAND_READ, &ec->common.command_addr);
+	acpi_hw_low_level_write(8, ACPI_EC_COMMAND_READ,
+				&ec->common.command_addr);
 	status = acpi_ec_wait(ec, ACPI_EC_EVENT_IBE);
 	if (status) {
 		printk("read EC, IB not empty\n");
 	}
 
 	acpi_hw_low_level_write(8, address, &ec->common.data_addr);
-	status= acpi_ec_wait(ec, ACPI_EC_EVENT_OBF);
-	if (status){
+	status = acpi_ec_wait(ec, ACPI_EC_EVENT_OBF);
+	if (status) {
 		printk("read EC, OB not full\n");
 		goto end;
 	}
 	acpi_hw_low_level_read(8, data, &ec->common.data_addr);
 	ACPI_DEBUG_PRINT((ACPI_DB_INFO, "Read [%02x] from address [%02x]\n",
-		*data, address));
-	
-end:
+			  *data, address));
+
+      end:
 	acpi_ec_leave_burst_mode(ec);
 	up(&ec->burst.sem);
 
@@ -503,15 +457,10 @@ end:
 	return_VALUE(status);
 }
 
-
-static int
-acpi_ec_burst_write (
-	union acpi_ec		*ec,
-	u8			address,
-	u8			data)
+static int acpi_ec_burst_write(union acpi_ec *ec, u8 address, u8 data)
 {
-	int			status = 0;
-	u32			glk;
+	int status = 0;
+	u32 glk;
 
 	ACPI_FUNCTION_TRACE("acpi_ec_write");
 
@@ -530,25 +479,26 @@ acpi_ec_burst_write (
 	acpi_ec_enter_burst_mode(ec);
 
 	status = acpi_ec_wait(ec, ACPI_EC_EVENT_IBE);
-	if ( status) {
+	if (status) {
 		printk("write EC, IB not empty\n");
 	}
-	acpi_hw_low_level_write(8, ACPI_EC_COMMAND_WRITE, &ec->common.command_addr);
+	acpi_hw_low_level_write(8, ACPI_EC_COMMAND_WRITE,
+				&ec->common.command_addr);
 	status = acpi_ec_wait(ec, ACPI_EC_EVENT_IBE);
 	if (status) {
-		printk ("write EC, IB not empty\n");
+		printk("write EC, IB not empty\n");
 	}
 
 	acpi_hw_low_level_write(8, address, &ec->common.data_addr);
 	status = acpi_ec_wait(ec, ACPI_EC_EVENT_IBE);
-	if (status){
+	if (status) {
 		printk("write EC, IB not empty\n");
 	}
 
 	acpi_hw_low_level_write(8, data, &ec->common.data_addr);
 
 	ACPI_DEBUG_PRINT((ACPI_DB_INFO, "Wrote [%02x] to address [%02x]\n",
-		data, address));
+			  data, address));
 
 	acpi_ec_leave_burst_mode(ec);
 	up(&ec->burst.sem);
@@ -562,8 +512,7 @@ acpi_ec_burst_write (
 /*
  * Externally callable EC access functions. For now, assume 1 EC only
  */
-int
-ec_read(u8 addr, u8 *val)
+int ec_read(u8 addr, u8 * val)
 {
 	union acpi_ec *ec;
 	int err;
@@ -579,14 +528,13 @@ ec_read(u8 addr, u8 *val)
 	if (!err) {
 		*val = temp_data;
 		return 0;
-	}
-	else
+	} else
 		return err;
 }
+
 EXPORT_SYMBOL(ec_read);
 
-int
-ec_write(u8 addr, u8 val)
+int ec_write(u8 addr, u8 val)
 {
 	union acpi_ec *ec;
 	int err;
@@ -600,27 +548,22 @@ ec_write(u8 addr, u8 val)
 
 	return err;
 }
+
 EXPORT_SYMBOL(ec_write);
 
-static int
-acpi_ec_query (
-	union acpi_ec		*ec,
-	u32			*data)
+static int acpi_ec_query(union acpi_ec *ec, u32 * data)
 {
-	if (acpi_ec_polling_mode) 
+	if (acpi_ec_polling_mode)
 		return acpi_ec_polling_query(ec, data);
 	else
 		return acpi_ec_burst_query(ec, data);
 }
-static int
-acpi_ec_polling_query (
-	union acpi_ec		*ec,
-	u32			*data)
-{
-	int			result = 0;
-	acpi_status		status = AE_OK;
-	unsigned long		flags = 0;
-	u32			glk = 0;
+static int acpi_ec_polling_query(union acpi_ec *ec, u32 * data)
+{
+	int result = 0;
+	acpi_status status = AE_OK;
+	unsigned long flags = 0;
+	u32 glk = 0;
 
 	ACPI_FUNCTION_TRACE("acpi_ec_query");
 
@@ -642,7 +585,8 @@ acpi_ec_polling_query (
 	 */
 	spin_lock_irqsave(&ec->polling.lock, flags);
 
-	acpi_hw_low_level_write(8, ACPI_EC_COMMAND_QUERY, &ec->common.command_addr);
+	acpi_hw_low_level_write(8, ACPI_EC_COMMAND_QUERY,
+				&ec->common.command_addr);
 	result = acpi_ec_wait(ec, ACPI_EC_EVENT_OBF);
 	if (result)
 		goto end;
@@ -651,7 +595,7 @@ acpi_ec_polling_query (
 	if (!*data)
 		result = -ENODATA;
 
-end:
+      end:
 	spin_unlock_irqrestore(&ec->polling.lock, flags);
 
 	if (ec->common.global_lock)
@@ -659,13 +603,10 @@ end:
 
 	return_VALUE(result);
 }
-static int
-acpi_ec_burst_query (
-	union acpi_ec		*ec,
-	u32			*data)
+static int acpi_ec_burst_query(union acpi_ec *ec, u32 * data)
 {
-	int			status = 0;
-	u32			glk;
+	int status = 0;
+	u32 glk;
 
 	ACPI_FUNCTION_TRACE("acpi_ec_query");
 
@@ -691,9 +632,10 @@ acpi_ec_burst_query (
 	 * Note that successful completion of the query causes the ACPI_EC_SCI
 	 * bit to be cleared (and thus clearing the interrupt source).
 	 */
-	acpi_hw_low_level_write(8, ACPI_EC_COMMAND_QUERY, &ec->common.command_addr);
+	acpi_hw_low_level_write(8, ACPI_EC_COMMAND_QUERY,
+				&ec->common.command_addr);
 	status = acpi_ec_wait(ec, ACPI_EC_EVENT_OBF);
-	if (status){
+	if (status) {
 		printk("query EC, OB not full\n");
 		goto end;
 	}
@@ -702,7 +644,7 @@ acpi_ec_burst_query (
 	if (!*data)
 		status = -ENODATA;
 
-end:
+      end:
 	up(&ec->burst.sem);
 
 	if (ec->common.global_lock)
@@ -711,36 +653,32 @@ end:
 	return_VALUE(status);
 }
 
-
 /* --------------------------------------------------------------------------
                                 Event Management
    -------------------------------------------------------------------------- */
 
 union acpi_ec_query_data {
-	acpi_handle		handle;
-	u8			data;
+	acpi_handle handle;
+	u8 data;
 };
 
-static void
-acpi_ec_gpe_query (
-	void			*ec_cxt)
+static void acpi_ec_gpe_query(void *ec_cxt)
 {
-	if (acpi_ec_polling_mode) 
+	if (acpi_ec_polling_mode)
 		acpi_ec_gpe_polling_query(ec_cxt);
 	else
 		acpi_ec_gpe_burst_query(ec_cxt);
 }
 
-static void
-acpi_ec_gpe_polling_query (
-	void			*ec_cxt)
-{
-	union acpi_ec		*ec = (union acpi_ec *) ec_cxt;
-	u32			value = 0;
-	unsigned long		flags = 0;
-	static char		object_name[5] = {'_','Q','0','0','\0'};
-	const char		hex[] = {'0','1','2','3','4','5','6','7',
-				         '8','9','A','B','C','D','E','F'};
+static void acpi_ec_gpe_polling_query(void *ec_cxt)
+{
+	union acpi_ec *ec = (union acpi_ec *)ec_cxt;
+	u32 value = 0;
+	unsigned long flags = 0;
+	static char object_name[5] = { '_', 'Q', '0', '0', '\0' };
+	const char hex[] = { '0', '1', '2', '3', '4', '5', '6', '7',
+		'8', '9', 'A', 'B', 'C', 'D', 'E', 'F'
+	};
 
 	ACPI_FUNCTION_TRACE("acpi_ec_gpe_query");
 
@@ -770,19 +708,18 @@ acpi_ec_gpe_polling_query (
 
 	acpi_evaluate_object(ec->common.handle, object_name, NULL, NULL);
 
-end:	
+      end:
 	acpi_enable_gpe(NULL, ec->common.gpe_bit, ACPI_NOT_ISR);
 }
-static void
-acpi_ec_gpe_burst_query (
-	void			*ec_cxt)
-{
-	union acpi_ec		*ec = (union acpi_ec *) ec_cxt;
-	u32			value;
-	int			result = -ENODATA;
-	static char		object_name[5] = {'_','Q','0','0','\0'};
-	const char		hex[] = {'0','1','2','3','4','5','6','7',
-				         '8','9','A','B','C','D','E','F'};
+static void acpi_ec_gpe_burst_query(void *ec_cxt)
+{
+	union acpi_ec *ec = (union acpi_ec *)ec_cxt;
+	u32 value;
+	int result = -ENODATA;
+	static char object_name[5] = { '_', 'Q', '0', '0', '\0' };
+	const char hex[] = { '0', '1', '2', '3', '4', '5', '6', '7',
+		'8', '9', 'A', 'B', 'C', 'D', 'E', 'F'
+	};
 
 	ACPI_FUNCTION_TRACE("acpi_ec_gpe_query");
 
@@ -798,26 +735,22 @@ acpi_ec_gpe_burst_query (
 	ACPI_DEBUG_PRINT((ACPI_DB_INFO, "Evaluating %s\n", object_name));
 
 	acpi_evaluate_object(ec->common.handle, object_name, NULL, NULL);
-end:	
+      end:
 	atomic_dec(&ec->burst.pending_gpe);
 	return;
 }
 
-static u32
-acpi_ec_gpe_handler (
-	void			*data)
+static u32 acpi_ec_gpe_handler(void *data)
 {
-	if (acpi_ec_polling_mode) 
+	if (acpi_ec_polling_mode)
 		return acpi_ec_gpe_polling_handler(data);
 	else
-		return acpi_ec_gpe_burst_handler(data);	
+		return acpi_ec_gpe_burst_handler(data);
 }
-static u32
-acpi_ec_gpe_polling_handler (
-	void			*data)
+static u32 acpi_ec_gpe_polling_handler(void *data)
 {
-	acpi_status		status = AE_OK;
-	union acpi_ec		*ec = (union acpi_ec *) data;
+	acpi_status status = AE_OK;
+	union acpi_ec *ec = (union acpi_ec *)data;
 
 	if (!ec)
 		return ACPI_INTERRUPT_NOT_HANDLED;
@@ -825,20 +758,18 @@ acpi_ec_gpe_polling_handler (
 	acpi_disable_gpe(NULL, ec->common.gpe_bit, ACPI_ISR);
 
 	status = acpi_os_queue_for_execution(OSD_PRIORITY_GPE,
-		acpi_ec_gpe_query, ec);
+					     acpi_ec_gpe_query, ec);
 
 	if (status == AE_OK)
 		return ACPI_INTERRUPT_HANDLED;
 	else
 		return ACPI_INTERRUPT_NOT_HANDLED;
 }
-static u32
-acpi_ec_gpe_burst_handler (
-	void			*data)
-{
-	acpi_status		status = AE_OK;
-	u32			value;
-	union acpi_ec		*ec = (union acpi_ec *) data;
+static u32 acpi_ec_gpe_burst_handler(void *data)
+{
+	acpi_status status = AE_OK;
+	u32 value;
+	union acpi_ec *ec = (union acpi_ec *)data;
 
 	if (!ec)
 		return ACPI_INTERRUPT_NOT_HANDLED;
@@ -846,7 +777,7 @@ acpi_ec_gpe_burst_handler (
 	acpi_clear_gpe(NULL, ec->common.gpe_bit, ACPI_ISR);
 	value = acpi_ec_read_status(ec);
 
-	switch ( ec->burst.expect_event) {
+	switch (ec->burst.expect_event) {
 	case ACPI_EC_EVENT_OBF:
 		if (!(value & ACPI_EC_FLAG_OBF))
 			break;
@@ -860,16 +791,16 @@ acpi_ec_gpe_burst_handler (
 		break;
 	}
 
-	if (value & ACPI_EC_FLAG_SCI){
-		atomic_add(1, &ec->burst.pending_gpe) ;
+	if (value & ACPI_EC_FLAG_SCI) {
+		atomic_add(1, &ec->burst.pending_gpe);
 		status = acpi_os_queue_for_execution(OSD_PRIORITY_GPE,
-						acpi_ec_gpe_query, ec);
+						     acpi_ec_gpe_query, ec);
 		return status == AE_OK ?
-		ACPI_INTERRUPT_HANDLED : ACPI_INTERRUPT_NOT_HANDLED;
-	} 
+		    ACPI_INTERRUPT_HANDLED : ACPI_INTERRUPT_NOT_HANDLED;
+	}
 	acpi_enable_gpe(NULL, ec->common.gpe_bit, ACPI_ISR);
 	return status == AE_OK ?
-		ACPI_INTERRUPT_HANDLED : ACPI_INTERRUPT_NOT_HANDLED;
+	    ACPI_INTERRUPT_HANDLED : ACPI_INTERRUPT_NOT_HANDLED;
 }
 
 /* --------------------------------------------------------------------------
@@ -877,37 +808,31 @@ acpi_ec_gpe_burst_handler (
    -------------------------------------------------------------------------- */
 
 static acpi_status
-acpi_ec_space_setup (
-	acpi_handle		region_handle,
-	u32			function,
-	void			*handler_context,
-	void			**return_context)
+acpi_ec_space_setup(acpi_handle region_handle,
+		    u32 function, void *handler_context, void **return_context)
 {
 	/*
 	 * The EC object is in the handler context and is needed
 	 * when calling the acpi_ec_space_handler.
 	 */
-	*return_context  = (function != ACPI_REGION_DEACTIVATE) ?
-						handler_context : NULL;
+	*return_context = (function != ACPI_REGION_DEACTIVATE) ?
+	    handler_context : NULL;
 
 	return AE_OK;
 }
 
-
 static acpi_status
-acpi_ec_space_handler (
-	u32			function,
-	acpi_physical_address	address,
-	u32			bit_width,
-	acpi_integer		*value,
-	void			*handler_context,
-	void			*region_context)
-{
-	int			result = 0;
-	union acpi_ec		*ec = NULL;
-	u64			temp = *value;
-	acpi_integer		f_v = 0;
-	int 			i = 0;
+acpi_ec_space_handler(u32 function,
+		      acpi_physical_address address,
+		      u32 bit_width,
+		      acpi_integer * value,
+		      void *handler_context, void *region_context)
+{
+	int result = 0;
+	union acpi_ec *ec = NULL;
+	u64 temp = *value;
+	acpi_integer f_v = 0;
+	int i = 0;
 
 	ACPI_FUNCTION_TRACE("acpi_ec_space_handler");
 
@@ -915,17 +840,18 @@ acpi_ec_space_handler (
 		return_VALUE(AE_BAD_PARAMETER);
 
 	if (bit_width != 8 && acpi_strict) {
-		printk(KERN_WARNING PREFIX "acpi_ec_space_handler: bit_width should be 8\n");
+		printk(KERN_WARNING PREFIX
+		       "acpi_ec_space_handler: bit_width should be 8\n");
 		return_VALUE(AE_BAD_PARAMETER);
 	}
 
-	ec = (union acpi_ec *) handler_context;
+	ec = (union acpi_ec *)handler_context;
 
-next_byte:
+      next_byte:
 	switch (function) {
 	case ACPI_READ:
 		temp = 0;
-		result = acpi_ec_read(ec, (u8) address, (u32 *)&temp);
+		result = acpi_ec_read(ec, (u8) address, (u32 *) & temp);
 		break;
 	case ACPI_WRITE:
 		result = acpi_ec_write(ec, (u8) address, (u8) temp);
@@ -952,8 +878,7 @@ next_byte:
 		*value = f_v;
 	}
 
-		
-out:
+      out:
 	switch (result) {
 	case -EINVAL:
 		return_VALUE(AE_BAD_PARAMETER);
@@ -969,18 +894,15 @@ out:
 	}
 }
 
-
 /* --------------------------------------------------------------------------
                               FS Interface (/proc)
    -------------------------------------------------------------------------- */
 
-static struct proc_dir_entry	*acpi_ec_dir;
+static struct proc_dir_entry *acpi_ec_dir;
 
-
-static int
-acpi_ec_read_info (struct seq_file *seq, void *offset)
+static int acpi_ec_read_info(struct seq_file *seq, void *offset)
 {
-	union acpi_ec		*ec = (union acpi_ec *) seq->private;
+	union acpi_ec *ec = (union acpi_ec *)seq->private;
 
 	ACPI_FUNCTION_TRACE("acpi_ec_read_info");
 
@@ -988,14 +910,15 @@ acpi_ec_read_info (struct seq_file *seq,
 		goto end;
 
 	seq_printf(seq, "gpe bit:                 0x%02x\n",
-		(u32) ec->common.gpe_bit);
+		   (u32) ec->common.gpe_bit);
 	seq_printf(seq, "ports:                   0x%02x, 0x%02x\n",
-		(u32) ec->common.status_addr.address, (u32) ec->common.data_addr.address);
+		   (u32) ec->common.status_addr.address,
+		   (u32) ec->common.data_addr.address);
 	seq_printf(seq, "use global lock:         %s\n",
-		ec->common.global_lock?"yes":"no");
+		   ec->common.global_lock ? "yes" : "no");
 	acpi_enable_gpe(NULL, ec->common.gpe_bit, ACPI_NOT_ISR);
 
-end:
+      end:
 	return_VALUE(0);
 }
 
@@ -1005,34 +928,32 @@ static int acpi_ec_info_open_fs(struct i
 }
 
 static struct file_operations acpi_ec_info_ops = {
-	.open		= acpi_ec_info_open_fs,
-	.read		= seq_read,
-	.llseek		= seq_lseek,
-	.release	= single_release,
+	.open = acpi_ec_info_open_fs,
+	.read = seq_read,
+	.llseek = seq_lseek,
+	.release = single_release,
 	.owner = THIS_MODULE,
 };
 
-static int
-acpi_ec_add_fs (
-	struct acpi_device	*device)
+static int acpi_ec_add_fs(struct acpi_device *device)
 {
-	struct proc_dir_entry	*entry = NULL;
+	struct proc_dir_entry *entry = NULL;
 
 	ACPI_FUNCTION_TRACE("acpi_ec_add_fs");
 
 	if (!acpi_device_dir(device)) {
 		acpi_device_dir(device) = proc_mkdir(acpi_device_bid(device),
-			acpi_ec_dir);
+						     acpi_ec_dir);
 		if (!acpi_device_dir(device))
 			return_VALUE(-ENODEV);
 	}
 
 	entry = create_proc_entry(ACPI_EC_FILE_INFO, S_IRUGO,
-		acpi_device_dir(device));
+				  acpi_device_dir(device));
 	if (!entry)
 		ACPI_DEBUG_PRINT((ACPI_DB_WARN,
-			"Unable to create '%s' fs entry\n",
-			ACPI_EC_FILE_INFO));
+				  "Unable to create '%s' fs entry\n",
+				  ACPI_EC_FILE_INFO));
 	else {
 		entry->proc_fops = &acpi_ec_info_ops;
 		entry->data = acpi_driver_data(device);
@@ -1042,10 +963,7 @@ acpi_ec_add_fs (
 	return_VALUE(0);
 }
 
-
-static int
-acpi_ec_remove_fs (
-	struct acpi_device	*device)
+static int acpi_ec_remove_fs(struct acpi_device *device)
 {
 	ACPI_FUNCTION_TRACE("acpi_ec_remove_fs");
 
@@ -1058,20 +976,16 @@ acpi_ec_remove_fs (
 	return_VALUE(0);
 }
 
-
 /* --------------------------------------------------------------------------
                                Driver Interface
    -------------------------------------------------------------------------- */
 
-
-static int
-acpi_ec_polling_add (
-	struct acpi_device	*device)
-{
-	int			result = 0;
-	acpi_status		status = AE_OK;
-	union acpi_ec		*ec = NULL;
-	unsigned long		uid;
+static int acpi_ec_polling_add(struct acpi_device *device)
+{
+	int result = 0;
+	acpi_status status = AE_OK;
+	union acpi_ec *ec = NULL;
+	unsigned long uid;
 
 	ACPI_FUNCTION_TRACE("acpi_ec_add");
 
@@ -1091,26 +1005,31 @@ acpi_ec_polling_add (
 	acpi_driver_data(device) = ec;
 
 	/* Use the global lock for all EC transactions? */
-	acpi_evaluate_integer(ec->common.handle, "_GLK", NULL, &ec->common.global_lock);
+	acpi_evaluate_integer(ec->common.handle, "_GLK", NULL,
+			      &ec->common.global_lock);
 
 	/* If our UID matches the UID for the ECDT-enumerated EC,
-	   we now have the *real* EC info, so kill the makeshift one.*/
+	   we now have the *real* EC info, so kill the makeshift one. */
 	acpi_evaluate_integer(ec->common.handle, "_UID", NULL, &uid);
 	if (ec_ecdt && ec_ecdt->common.uid == uid) {
 		acpi_remove_address_space_handler(ACPI_ROOT_OBJECT,
-			ACPI_ADR_SPACE_EC, &acpi_ec_space_handler);
-	
-		acpi_remove_gpe_handler(NULL, ec_ecdt->common.gpe_bit, &acpi_ec_gpe_handler);
+						  ACPI_ADR_SPACE_EC,
+						  &acpi_ec_space_handler);
+
+		acpi_remove_gpe_handler(NULL, ec_ecdt->common.gpe_bit,
+					&acpi_ec_gpe_handler);
 
 		kfree(ec_ecdt);
 	}
 
 	/* Get GPE bit assignment (EC events). */
 	/* TODO: Add support for _GPE returning a package */
-	status = acpi_evaluate_integer(ec->common.handle, "_GPE", NULL, &ec->common.gpe_bit);
+	status =
+	    acpi_evaluate_integer(ec->common.handle, "_GPE", NULL,
+				  &ec->common.gpe_bit);
 	if (ACPI_FAILURE(status)) {
 		ACPI_DEBUG_PRINT((ACPI_DB_ERROR,
-			"Error obtaining GPE bit assignment\n"));
+				  "Error obtaining GPE bit assignment\n"));
 		result = -ENODEV;
 		goto end;
 	}
@@ -1120,26 +1039,24 @@ acpi_ec_polling_add (
 		goto end;
 
 	printk(KERN_INFO PREFIX "%s [%s] (gpe %d)\n",
-		acpi_device_name(device), acpi_device_bid(device),
-		(u32) ec->common.gpe_bit);
+	       acpi_device_name(device), acpi_device_bid(device),
+	       (u32) ec->common.gpe_bit);
 
 	if (!first_ec)
 		first_ec = device;
 
-end:
+      end:
 	if (result)
 		kfree(ec);
 
 	return_VALUE(result);
 }
-static int
-acpi_ec_burst_add (
-	struct acpi_device	*device)
-{
-	int			result = 0;
-	acpi_status		status = AE_OK;
-	union acpi_ec		*ec = NULL;
-	unsigned long		uid;
+static int acpi_ec_burst_add(struct acpi_device *device)
+{
+	int result = 0;
+	acpi_status status = AE_OK;
+	union acpi_ec *ec = NULL;
+	unsigned long uid;
 
 	ACPI_FUNCTION_TRACE("acpi_ec_add");
 
@@ -1153,35 +1070,40 @@ acpi_ec_burst_add (
 
 	ec->common.handle = device->handle;
 	ec->common.uid = -1;
- 	atomic_set(&ec->burst.pending_gpe, 0);
- 	atomic_set(&ec->burst.leaving_burst , 1);
- 	init_MUTEX(&ec->burst.sem);
- 	init_waitqueue_head(&ec->burst.wait);
+	atomic_set(&ec->burst.pending_gpe, 0);
+	atomic_set(&ec->burst.leaving_burst, 1);
+	init_MUTEX(&ec->burst.sem);
+	init_waitqueue_head(&ec->burst.wait);
 	strcpy(acpi_device_name(device), ACPI_EC_DEVICE_NAME);
 	strcpy(acpi_device_class(device), ACPI_EC_CLASS);
 	acpi_driver_data(device) = ec;
 
 	/* Use the global lock for all EC transactions? */
-	acpi_evaluate_integer(ec->common.handle, "_GLK", NULL, &ec->common.global_lock);
+	acpi_evaluate_integer(ec->common.handle, "_GLK", NULL,
+			      &ec->common.global_lock);
 
 	/* If our UID matches the UID for the ECDT-enumerated EC,
-	   we now have the *real* EC info, so kill the makeshift one.*/
+	   we now have the *real* EC info, so kill the makeshift one. */
 	acpi_evaluate_integer(ec->common.handle, "_UID", NULL, &uid);
 	if (ec_ecdt && ec_ecdt->common.uid == uid) {
 		acpi_remove_address_space_handler(ACPI_ROOT_OBJECT,
-			ACPI_ADR_SPACE_EC, &acpi_ec_space_handler);
+						  ACPI_ADR_SPACE_EC,
+						  &acpi_ec_space_handler);
 
-		acpi_remove_gpe_handler(NULL, ec_ecdt->common.gpe_bit, &acpi_ec_gpe_handler);
+		acpi_remove_gpe_handler(NULL, ec_ecdt->common.gpe_bit,
+					&acpi_ec_gpe_handler);
 
 		kfree(ec_ecdt);
 	}
 
 	/* Get GPE bit assignment (EC events). */
 	/* TODO: Add support for _GPE returning a package */
-	status = acpi_evaluate_integer(ec->common.handle, "_GPE", NULL, &ec->common.gpe_bit);
+	status =
+	    acpi_evaluate_integer(ec->common.handle, "_GPE", NULL,
+				  &ec->common.gpe_bit);
 	if (ACPI_FAILURE(status)) {
 		ACPI_DEBUG_PRINT((ACPI_DB_ERROR,
-			"Error obtaining GPE bit assignment\n"));
+				  "Error obtaining GPE bit assignment\n"));
 		result = -ENODEV;
 		goto end;
 	}
@@ -1192,26 +1114,22 @@ acpi_ec_burst_add (
 
 	printk("burst-mode-ec-10-Aug\n");
 	printk(KERN_INFO PREFIX "%s [%s] (gpe %d)\n",
-		acpi_device_name(device), acpi_device_bid(device),
-		(u32) ec->common.gpe_bit);
+	       acpi_device_name(device), acpi_device_bid(device),
+	       (u32) ec->common.gpe_bit);
 
 	if (!first_ec)
 		first_ec = device;
 
-end:
+      end:
 	if (result)
 		kfree(ec);
 
 	return_VALUE(result);
 }
 
-
-static int
-acpi_ec_remove (
-	struct acpi_device	*device,
-	int			type)
+static int acpi_ec_remove(struct acpi_device *device, int type)
 {
-	union acpi_ec		*ec = NULL;
+	union acpi_ec *ec = NULL;
 
 	ACPI_FUNCTION_TRACE("acpi_ec_remove");
 
@@ -1227,13 +1145,10 @@ acpi_ec_remove (
 	return_VALUE(0);
 }
 
-
 static acpi_status
-acpi_ec_io_ports (
-	struct acpi_resource	*resource,
-	void			*context)
+acpi_ec_io_ports(struct acpi_resource *resource, void *context)
 {
-	union acpi_ec		*ec = (union acpi_ec *) context;
+	union acpi_ec *ec = (union acpi_ec *)context;
 	struct acpi_generic_address *addr;
 
 	if (resource->id != ACPI_RSTYPE_IO) {
@@ -1261,13 +1176,10 @@ acpi_ec_io_ports (
 	return AE_OK;
 }
 
-
-static int
-acpi_ec_start (
-	struct acpi_device	*device)
+static int acpi_ec_start(struct acpi_device *device)
 {
-	acpi_status		status = AE_OK;
-	union acpi_ec		*ec = NULL;
+	acpi_status status = AE_OK;
+	union acpi_ec *ec = NULL;
 
 	ACPI_FUNCTION_TRACE("acpi_ec_start");
 
@@ -1283,49 +1195,50 @@ acpi_ec_start (
 	 * Get I/O port addresses. Convert to GAS format.
 	 */
 	status = acpi_walk_resources(ec->common.handle, METHOD_NAME__CRS,
-		acpi_ec_io_ports, ec);
-	if (ACPI_FAILURE(status) || ec->common.command_addr.register_bit_width == 0) {
-		ACPI_DEBUG_PRINT((ACPI_DB_ERROR, "Error getting I/O port addresses"));
+				     acpi_ec_io_ports, ec);
+	if (ACPI_FAILURE(status)
+	    || ec->common.command_addr.register_bit_width == 0) {
+		ACPI_DEBUG_PRINT((ACPI_DB_ERROR,
+				  "Error getting I/O port addresses"));
 		return_VALUE(-ENODEV);
 	}
 
 	ec->common.status_addr = ec->common.command_addr;
 
 	ACPI_DEBUG_PRINT((ACPI_DB_INFO, "gpe=0x%02x, ports=0x%2x,0x%2x\n",
-		(u32) ec->common.gpe_bit, (u32) ec->common.command_addr.address,
-		(u32) ec->common.data_addr.address));
-
+			  (u32) ec->common.gpe_bit,
+			  (u32) ec->common.command_addr.address,
+			  (u32) ec->common.data_addr.address));
 
 	/*
 	 * Install GPE handler
 	 */
 	status = acpi_install_gpe_handler(NULL, ec->common.gpe_bit,
-		ACPI_GPE_EDGE_TRIGGERED, &acpi_ec_gpe_handler, ec);
+					  ACPI_GPE_EDGE_TRIGGERED,
+					  &acpi_ec_gpe_handler, ec);
 	if (ACPI_FAILURE(status)) {
 		return_VALUE(-ENODEV);
 	}
-	acpi_set_gpe_type (NULL, ec->common.gpe_bit, ACPI_GPE_TYPE_RUNTIME);
-	acpi_enable_gpe (NULL, ec->common.gpe_bit, ACPI_NOT_ISR);
+	acpi_set_gpe_type(NULL, ec->common.gpe_bit, ACPI_GPE_TYPE_RUNTIME);
+	acpi_enable_gpe(NULL, ec->common.gpe_bit, ACPI_NOT_ISR);
 
-	status = acpi_install_address_space_handler (ec->common.handle,
-			ACPI_ADR_SPACE_EC, &acpi_ec_space_handler,
-			&acpi_ec_space_setup, ec);
+	status = acpi_install_address_space_handler(ec->common.handle,
+						    ACPI_ADR_SPACE_EC,
+						    &acpi_ec_space_handler,
+						    &acpi_ec_space_setup, ec);
 	if (ACPI_FAILURE(status)) {
-		acpi_remove_gpe_handler(NULL, ec->common.gpe_bit, &acpi_ec_gpe_handler);
+		acpi_remove_gpe_handler(NULL, ec->common.gpe_bit,
+					&acpi_ec_gpe_handler);
 		return_VALUE(-ENODEV);
 	}
 
 	return_VALUE(AE_OK);
 }
 
-
-static int
-acpi_ec_stop (
-	struct acpi_device	*device,
-	int			type)
+static int acpi_ec_stop(struct acpi_device *device, int type)
 {
-	acpi_status		status = AE_OK;
-	union acpi_ec		*ec = NULL;
+	acpi_status status = AE_OK;
+	union acpi_ec *ec = NULL;
 
 	ACPI_FUNCTION_TRACE("acpi_ec_stop");
 
@@ -1335,11 +1248,14 @@ acpi_ec_stop (
 	ec = acpi_driver_data(device);
 
 	status = acpi_remove_address_space_handler(ec->common.handle,
-		ACPI_ADR_SPACE_EC, &acpi_ec_space_handler);
+						   ACPI_ADR_SPACE_EC,
+						   &acpi_ec_space_handler);
 	if (ACPI_FAILURE(status))
 		return_VALUE(-ENODEV);
 
-	status = acpi_remove_gpe_handler(NULL, ec->common.gpe_bit, &acpi_ec_gpe_handler);
+	status =
+	    acpi_remove_gpe_handler(NULL, ec->common.gpe_bit,
+				    &acpi_ec_gpe_handler);
 	if (ACPI_FAILURE(status))
 		return_VALUE(-ENODEV);
 
@@ -1347,32 +1263,26 @@ acpi_ec_stop (
 }
 
 static acpi_status __init
-acpi_fake_ecdt_callback (
-	acpi_handle	handle,
-	u32		Level,
-	void		*context,
-	void		**retval)
+acpi_fake_ecdt_callback(acpi_handle handle,
+			u32 Level, void *context, void **retval)
 {
 
 	if (acpi_ec_polling_mode)
 		return acpi_fake_ecdt_polling_callback(handle,
-			Level, context, retval);
+						       Level, context, retval);
 	else
 		return acpi_fake_ecdt_burst_callback(handle,
-			Level, context, retval);
+						     Level, context, retval);
 }
 
 static acpi_status __init
-acpi_fake_ecdt_polling_callback (
-	acpi_handle	handle,
-	u32		Level,
-	void		*context,
-	void		**retval)
+acpi_fake_ecdt_polling_callback(acpi_handle handle,
+				u32 Level, void *context, void **retval)
 {
-	acpi_status	status;
+	acpi_status status;
 
 	status = acpi_walk_resources(handle, METHOD_NAME__CRS,
-		acpi_ec_io_ports, ec_ecdt);
+				     acpi_ec_io_ports, ec_ecdt);
 	if (ACPI_FAILURE(status))
 		return status;
 	ec_ecdt->common.status_addr = ec_ecdt->common.command_addr;
@@ -1380,33 +1290,33 @@ acpi_fake_ecdt_polling_callback (
 	ec_ecdt->common.uid = -1;
 	acpi_evaluate_integer(handle, "_UID", NULL, &ec_ecdt->common.uid);
 
-	status = acpi_evaluate_integer(handle, "_GPE", NULL, &ec_ecdt->common.gpe_bit);
+	status =
+	    acpi_evaluate_integer(handle, "_GPE", NULL,
+				  &ec_ecdt->common.gpe_bit);
 	if (ACPI_FAILURE(status))
 		return status;
 	spin_lock_init(&ec_ecdt->polling.lock);
 	ec_ecdt->common.global_lock = TRUE;
 	ec_ecdt->common.handle = handle;
 
-	printk(KERN_INFO PREFIX  "GPE=0x%02x, ports=0x%2x, 0x%2x\n",
-		(u32) ec_ecdt->common.gpe_bit, (u32) ec_ecdt->common.command_addr.address,
-		(u32) ec_ecdt->common.data_addr.address);
+	printk(KERN_INFO PREFIX "GPE=0x%02x, ports=0x%2x, 0x%2x\n",
+	       (u32) ec_ecdt->common.gpe_bit,
+	       (u32) ec_ecdt->common.command_addr.address,
+	       (u32) ec_ecdt->common.data_addr.address);
 
 	return AE_CTRL_TERMINATE;
 }
 
 static acpi_status __init
-acpi_fake_ecdt_burst_callback (
-	acpi_handle	handle,
-	u32		Level,
-	void		*context,
-	void		**retval)
+acpi_fake_ecdt_burst_callback(acpi_handle handle,
+			      u32 Level, void *context, void **retval)
 {
-	acpi_status	status;
+	acpi_status status;
 
 	init_MUTEX(&ec_ecdt->burst.sem);
 	init_waitqueue_head(&ec_ecdt->burst.wait);
 	status = acpi_walk_resources(handle, METHOD_NAME__CRS,
-		acpi_ec_io_ports, ec_ecdt);
+				     acpi_ec_io_ports, ec_ecdt);
 	if (ACPI_FAILURE(status))
 		return status;
 	ec_ecdt->common.status_addr = ec_ecdt->common.command_addr;
@@ -1414,15 +1324,18 @@ acpi_fake_ecdt_burst_callback (
 	ec_ecdt->common.uid = -1;
 	acpi_evaluate_integer(handle, "_UID", NULL, &ec_ecdt->common.uid);
 
-	status = acpi_evaluate_integer(handle, "_GPE", NULL, &ec_ecdt->common.gpe_bit);
+	status =
+	    acpi_evaluate_integer(handle, "_GPE", NULL,
+				  &ec_ecdt->common.gpe_bit);
 	if (ACPI_FAILURE(status))
 		return status;
 	ec_ecdt->common.global_lock = TRUE;
 	ec_ecdt->common.handle = handle;
 
-	printk(KERN_INFO PREFIX  "GPE=0x%02x, ports=0x%2x, 0x%2x\n",
-		(u32) ec_ecdt->common.gpe_bit, (u32) ec_ecdt->common.command_addr.address,
-		(u32) ec_ecdt->common.data_addr.address);
+	printk(KERN_INFO PREFIX "GPE=0x%02x, ports=0x%2x, 0x%2x\n",
+	       (u32) ec_ecdt->common.gpe_bit,
+	       (u32) ec_ecdt->common.command_addr.address,
+	       (u32) ec_ecdt->common.data_addr.address);
 
 	return AE_CTRL_TERMINATE;
 }
@@ -1437,11 +1350,10 @@ acpi_fake_ecdt_burst_callback (
  * op region (since _REG isn't invoked yet). The assumption is true for
  * all systems found.
  */
-static int __init
-acpi_ec_fake_ecdt(void)
+static int __init acpi_ec_fake_ecdt(void)
 {
-	acpi_status	status;
-	int		ret = 0;
+	acpi_status status;
+	int ret = 0;
 
 	printk(KERN_INFO PREFIX "Try to make an fake ECDT\n");
 
@@ -1452,10 +1364,8 @@ acpi_ec_fake_ecdt(void)
 	}
 	memset(ec_ecdt, 0, sizeof(union acpi_ec));
 
-	status = acpi_get_devices (ACPI_EC_HID,
-				acpi_fake_ecdt_callback,
-				NULL,
-				NULL);
+	status = acpi_get_devices(ACPI_EC_HID,
+				  acpi_fake_ecdt_callback, NULL, NULL);
 	if (ACPI_FAILURE(status)) {
 		kfree(ec_ecdt);
 		ec_ecdt = NULL;
@@ -1463,13 +1373,12 @@ acpi_ec_fake_ecdt(void)
 		goto error;
 	}
 	return 0;
-error:
+      error:
 	printk(KERN_ERR PREFIX "Can't make an fake ECDT\n");
 	return ret;
 }
 
-static int __init
-acpi_ec_get_real_ecdt(void)
+static int __init acpi_ec_get_real_ecdt(void)
 {
 	if (acpi_ec_polling_mode)
 		return acpi_ec_polling_get_real_ecdt();
@@ -1477,14 +1386,14 @@ acpi_ec_get_real_ecdt(void)
 		return acpi_ec_burst_get_real_ecdt();
 }
 
-static int __init
-acpi_ec_polling_get_real_ecdt(void)
+static int __init acpi_ec_polling_get_real_ecdt(void)
 {
-	acpi_status		status;
-	struct acpi_table_ecdt 	*ecdt_ptr;
+	acpi_status status;
+	struct acpi_table_ecdt *ecdt_ptr;
 
-	status = acpi_get_firmware_table("ECDT", 1, ACPI_LOGICAL_ADDRESSING, 
-		(struct acpi_table_header **) &ecdt_ptr);
+	status = acpi_get_firmware_table("ECDT", 1, ACPI_LOGICAL_ADDRESSING,
+					 (struct acpi_table_header **)
+					 &ecdt_ptr);
 	if (ACPI_FAILURE(status))
 		return -ENODEV;
 
@@ -1507,13 +1416,14 @@ acpi_ec_polling_get_real_ecdt(void)
 	ec_ecdt->common.global_lock = TRUE;
 	ec_ecdt->common.uid = ecdt_ptr->uid;
 
-	status = acpi_get_handle(NULL, ecdt_ptr->ec_id, &ec_ecdt->common.handle);
+	status =
+	    acpi_get_handle(NULL, ecdt_ptr->ec_id, &ec_ecdt->common.handle);
 	if (ACPI_FAILURE(status)) {
 		goto error;
 	}
 
 	return 0;
-error:
+      error:
 	printk(KERN_ERR PREFIX "Could not use ECDT\n");
 	kfree(ec_ecdt);
 	ec_ecdt = NULL;
@@ -1521,15 +1431,14 @@ error:
 	return -ENODEV;
 }
 
-
-static int __init
-acpi_ec_burst_get_real_ecdt(void)
+static int __init acpi_ec_burst_get_real_ecdt(void)
 {
-	acpi_status		status;
-	struct acpi_table_ecdt 	*ecdt_ptr;
+	acpi_status status;
+	struct acpi_table_ecdt *ecdt_ptr;
 
 	status = acpi_get_firmware_table("ECDT", 1, ACPI_LOGICAL_ADDRESSING,
-		(struct acpi_table_header **) &ecdt_ptr);
+					 (struct acpi_table_header **)
+					 &ecdt_ptr);
 	if (ACPI_FAILURE(status))
 		return -ENODEV;
 
@@ -1543,8 +1452,8 @@ acpi_ec_burst_get_real_ecdt(void)
 		return -ENOMEM;
 	memset(ec_ecdt, 0, sizeof(union acpi_ec));
 
- 	init_MUTEX(&ec_ecdt->burst.sem);
- 	init_waitqueue_head(&ec_ecdt->burst.wait);
+	init_MUTEX(&ec_ecdt->burst.sem);
+	init_waitqueue_head(&ec_ecdt->burst.wait);
 	ec_ecdt->common.command_addr = ecdt_ptr->ec_control;
 	ec_ecdt->common.status_addr = ecdt_ptr->ec_control;
 	ec_ecdt->common.data_addr = ecdt_ptr->ec_data;
@@ -1553,13 +1462,14 @@ acpi_ec_burst_get_real_ecdt(void)
 	ec_ecdt->common.global_lock = TRUE;
 	ec_ecdt->common.uid = ecdt_ptr->uid;
 
-	status = acpi_get_handle(NULL, ecdt_ptr->ec_id, &ec_ecdt->common.handle);
+	status =
+	    acpi_get_handle(NULL, ecdt_ptr->ec_id, &ec_ecdt->common.handle);
 	if (ACPI_FAILURE(status)) {
 		goto error;
 	}
 
 	return 0;
-error:
+      error:
 	printk(KERN_ERR PREFIX "Could not use ECDT\n");
 	kfree(ec_ecdt);
 	ec_ecdt = NULL;
@@ -1568,11 +1478,10 @@ error:
 }
 
 static int __initdata acpi_fake_ecdt_enabled;
-int __init
-acpi_ec_ecdt_probe (void)
+int __init acpi_ec_ecdt_probe(void)
 {
-	acpi_status		status;
-	int			ret;
+	acpi_status status;
+	int ret;
 
 	ret = acpi_ec_get_real_ecdt();
 	/* Try to make a fake ECDT */
@@ -1587,26 +1496,28 @@ acpi_ec_ecdt_probe (void)
 	 * Install GPE handler
 	 */
 	status = acpi_install_gpe_handler(NULL, ec_ecdt->common.gpe_bit,
-		ACPI_GPE_EDGE_TRIGGERED, &acpi_ec_gpe_handler,
-		ec_ecdt);
+					  ACPI_GPE_EDGE_TRIGGERED,
+					  &acpi_ec_gpe_handler, ec_ecdt);
 	if (ACPI_FAILURE(status)) {
 		goto error;
 	}
-	acpi_set_gpe_type (NULL, ec_ecdt->common.gpe_bit, ACPI_GPE_TYPE_RUNTIME);
-	acpi_enable_gpe (NULL, ec_ecdt->common.gpe_bit, ACPI_NOT_ISR);
+	acpi_set_gpe_type(NULL, ec_ecdt->common.gpe_bit, ACPI_GPE_TYPE_RUNTIME);
+	acpi_enable_gpe(NULL, ec_ecdt->common.gpe_bit, ACPI_NOT_ISR);
 
-	status = acpi_install_address_space_handler (ACPI_ROOT_OBJECT,
-			ACPI_ADR_SPACE_EC, &acpi_ec_space_handler,
-			&acpi_ec_space_setup, ec_ecdt);
+	status = acpi_install_address_space_handler(ACPI_ROOT_OBJECT,
+						    ACPI_ADR_SPACE_EC,
+						    &acpi_ec_space_handler,
+						    &acpi_ec_space_setup,
+						    ec_ecdt);
 	if (ACPI_FAILURE(status)) {
 		acpi_remove_gpe_handler(NULL, ec_ecdt->common.gpe_bit,
-			&acpi_ec_gpe_handler);
+					&acpi_ec_gpe_handler);
 		goto error;
 	}
 
 	return 0;
 
-error:
+      error:
 	printk(KERN_ERR PREFIX "Could not use ECDT\n");
 	kfree(ec_ecdt);
 	ec_ecdt = NULL;
@@ -1614,10 +1525,9 @@ error:
 	return -ENODEV;
 }
 
-
-static int __init acpi_ec_init (void)
+static int __init acpi_ec_init(void)
 {
-	int			result = 0;
+	int result = 0;
 
 	ACPI_FUNCTION_TRACE("acpi_ec_init");
 
@@ -1642,8 +1552,7 @@ subsys_initcall(acpi_ec_init);
 
 /* EC driver currently not unloadable */
 #if 0
-static void __exit
-acpi_ec_exit (void)
+static void __exit acpi_ec_exit(void)
 {
 	ACPI_FUNCTION_TRACE("acpi_ec_exit");
 
@@ -1653,7 +1562,7 @@ acpi_ec_exit (void)
 
 	return_VOID;
 }
-#endif /* 0 */
+#endif				/* 0 */
 
 static int __init acpi_fake_ecdt_setup(char *str)
 {
@@ -1676,8 +1585,8 @@ static int __init acpi_ec_set_polling_mo
 		acpi_ec_polling_mode = EC_POLLING;
 		acpi_ec_driver.ops.add = acpi_ec_polling_add;
 	}
-	printk(KERN_INFO PREFIX "EC %s mode.\n",
-		burst ? "burst": "polling");
+	printk(KERN_INFO PREFIX "EC %s mode.\n", burst ? "burst" : "polling");
 	return 0;
 }
+
 __setup("ec_burst=", acpi_ec_set_polling_mode);
